function [pRand, pNIR,accNIR] = NIRTest(Correct,Ntrain,Ntest)
% [pRand, pNIR,accNIR] = NIRTest(Correct,Ntrain,Ntest)
%
% NIR test -- see the paper:
% 
% Manuele Bicego, Antonella Mensi: "Null/No Information Rate (NIR): a statistical 
% test to assess if a classification accuracy is significant for a given problem",
% arXiv preprint arXiv:2306.06140, 2023
%
% 
% Input:
% - Correct: number of objects in the testing set correctly classified
% - Ntrain = vector of c elements (c number of classes of the problem)
%       where
%       Ntrain(1) = number of objects of class 1 in the training set
%       Ntrain(2) = number of objects of class 2 in the training set
%       ...
% - Ntest = same format as Ntrain, but for the testing set
%
% Output:
% - pRand, pNIR: pvalues for the tests
% - accNIR: accuracy of the a priori classifier
% 
% (c) Manuele Bicego 
% University of Verona (Italy)
% Last update: June 2023
% 



% compute accuracies of "naive" classifiers
% Rand
C = length(Ntrain);
accRand = 1/C; % eq (3)

% A priori classifier
[~,a] = max(Ntrain); % most frequent class
Xa = Ntest(a); 
m = sum(Ntest);
accNIR = Xa/m; % eq (4)

acc = Correct/m; % eq (2)

if acc<= accRand | acc<=accNIR
    fprintf('Accuracies should be larger than A priori Classifier and Random Classifier\n');
    pRand = 1;
    pNIR = 1;
else
    tC = Correct;
    x = tC:m;

    % Test for NIR
    p = accNIR;
    y = binopdf(x,m,p);
    pNIR = sum(y);
    
    % Test for Rand
    p = accRand;
    y = binopdf(x,m,p);
    pRand = sum(y);
end
 
